#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nonempty-containers
version:              0.3.6.0
visibility:           public
id:                   nonempty-containers-0.3.6.0-4ZfR57epzrq4pAlmYtUOlJ
key:                  nonempty-containers-0.3.6.0-4ZfR57epzrq4pAlmYtUOlJ
license:              BSD-3-Clause
copyright:            (c) Justin Le 2018
maintainer:           justin@jle.im
author:               Justin Le
homepage:             https://github.com/mstksg/nonempty-containers#readme
synopsis:             Non-empty variants of containers data types, with full API
description:
    Efficient and optimized non-empty versions of types from /containers/.
    Inspired by /non-empty-containers/ library, except attempting a more
    faithful port (with under-the-hood optimizations) of the full /containers/
    API. Also contains a convenient typeclass abstraction for converting
    betwewen non-empty and possibly-empty variants. See README.md for more
    information.

category:             Data Structures
abi:                  f269a2ca85dd3a755df702acf0464e03
exposed:              True
exposed-modules:
    Data.Containers.NonEmpty Data.Containers.NonEmpty.List
    Data.IntMap.NonEmpty Data.IntMap.NonEmpty.Internal
    Data.IntSet.NonEmpty Data.IntSet.NonEmpty.Internal
    Data.Map.NonEmpty Data.Map.NonEmpty.Internal Data.Sequence.NonEmpty
    Data.Sequence.NonEmpty.Internal Data.Set.NonEmpty
    Data.Set.NonEmpty.Internal

hidden-modules:       Paths_nonempty_containers
import-dirs:          /usr/lib/ghc-9.6.6/site-local/nonempty-containers-0.3.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/nonempty-containers-0.3.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/nonempty-containers-0.3.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nonempty-containers
hs-libraries:         HSnonempty-containers-0.3.6.0-4ZfR57epzrq4pAlmYtUOlJ
depends:
    aeson-2.2.2.0-7c2B0clV8yIEXobemFKLly base-4.18.2.1
    comonad-5.0.10-9zmTmQAIprnFrwnYdWpp6g containers-0.6.7
    deepseq-1.4.8.1 indexed-traversable-0.1.5-joXpPaCxYw3UYRlFaP36
    invariant-0.6.5-85p7ilhPLp97P2za2w6gFz
    nonempty-vector-0.2.4-5iIt6nPnZFmLfFQMT4lrYu
    semigroupoids-6.0.2-EM42hf7QGx74z9TdpT30mc
    these-1.2.1-8b1XsW37fHKjRGbcPay34
    vector-0.13.2.0-8P1yhfNTE0VJ5EIM0TMJkk

haddock-interfaces:
    /usr/share/doc/haskell-nonempty-containers/html/nonempty-containers.haddock

haddock-html:         /usr/share/doc/haskell-nonempty-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

